
Changelog
=========

0.2.0 (2016-05-06)
------------------

* Allow using ":group" as argument, just like ``gosu`` (it will use the current user, but with the given group).

0.1.0 (2016-04-19)
------------------

* First release on PyPI.
